#
# spec file for package flannel
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           flannel
Version:        0.9.1
Release:        11.3
Summary:        An etcd backed network fabric for containers
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/coreos/flannel
Source:         %{name}-%{version}.tar.xz
Source1:        flanneld.sysconf
Source2:        flanneld.service
Source3:        flannel-docker.conf
Source4:        flannel-tmpfiles.conf
Patch1:         use-32-prefix-udp-backend.patch
BuildRequires:  golang-packaging
BuildRequires:  systemd
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.11
# go1.11.3 contains sec. fixes bsc#1118897(CVE-2018-16873) bsc#1118897(CVE-2018-16873) bsc#1118899(CVE-2018-16875)
BuildRequires:  go1.11 >= 1.11.3
Requires(post): %fillup_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    s390
%{go_nostrip}
%{go_provides}
%{?systemd_requires}

%description
flannel is a virtual network that gives a subnet to each host for use with
container runtimes.

Platforms like Google's Kubernetes assume that each container (pod) has a
unique, routable IP inside the cluster. The advantage of this model is that it
reduces the complexity of doing port mapping.

%prep
%setup -q
%patch1 -p1

%build
gofmt -w -r "x -> \"%{version}\"" version/version.go
%{goprep} github.com/coreos/flannel
%{gobuild}

%install
%{goinstall}
rm -rf %{buildroot}/%{_libdir}/go/contrib

# Service
install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/docker.service.d/flannel.conf

install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/flanneld.service
install -d %{buildroot}/%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcflanneld

# Sysconfig
install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_fillupdir}/sysconfig.flanneld
install -D -p -m 0644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# Additional
install -D -p -m 0755 dist/mk-docker-opts.sh %{buildroot}%{_libexecdir}/flannel/mk-docker-opts.sh

# Move
mv %{buildroot}%{_bindir}/flannel %{buildroot}%{_sbindir}/flanneld

%pre
%service_add_pre flanneld.service

%post
%service_add_post flanneld.service
%{_bindir}/systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf
%{fillup_only -n flanneld}

%preun
%service_del_preun flanneld.service

%postun
%service_del_postun flanneld.service

%files
%defattr(-,root,root)
%doc CONTRIBUTING.md README.md DCO NOTICE
%license LICENSE
%{_sbindir}/flanneld

# Service
%dir %{_unitdir}/docker.service.d
%{_unitdir}/docker.service.d/flannel.conf
%{_unitdir}/flanneld.service
%{_sbindir}/rcflanneld

# Sysconfig
%{_fillupdir}/sysconfig.flanneld
%{_tmpfilesdir}/%{name}.conf
%attr(0750,root,root) %dir %ghost %{_rundir}/%{name}

# Additional
%dir %{_libexecdir}/flannel
%{_libexecdir}/flannel/mk-docker-opts.sh

%changelog
* Wed Dec 19 2018 clee@suse.com
- Refactor go to go1.11 for BuildRequires
* Wed Dec 19 2018 clee@suse.com
- Updated to a supported version of Go (due to security reasons)
  * bsc#1118897 CVE-2018-16873
    go#29230 cmd/go: remote command execution during "go get -u"
  * bsc#1118898 CVE-2018-16874
    go#29231 cmd/go: directory traversal in "go get" via curly braces in import paths
  * bsc#1118899 CVE-2018-16875
    go#29233 crypto/x509: CPU denial of service
* Wed Dec 12 2018 alvaro.saurin@suse.com
- Updated to a supported version of Go (due to security reasons)
* Tue Jun  5 2018 dcassany@suse.com
- Make use of %%license macro
* Tue May 29 2018 rfernandezlopez@suse.com
- Add use-32-prefix-udp-backend.patch: backend/udp: Use a /32 prefix for the flannel0 interface
  This avoids the kernel's creation of broadcast routes, which prevent
  communication from the host with the zeroth subnet to containers on any
  other hosts.
  Fixes: bsc#1094364
* Thu Feb  1 2018 ro@suse.de
- do not build on s390, only on s390x (no go on s390)
* Mon Nov 27 2017 opensuse-packaging@opensuse.org
- Update to version 0.9.1:
  * kube: Update manifests to v0.9.1
  * network/iptables: Add iptables rules to FORWARD chain
  * kube-flannel.yml: Update to v0.9.0 and improve docs
  * Update README.md
  * Fix horrendous README typo
  * Always ensure iptables masquerade rules are installed
  * Makefile: Stop pulling the unused lib from kube-cross
  * subnet/*: Remove unused reservations code
  * use init container to install cni on flannel daemonset
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Aug 29 2017 mmeister@suse.com
- build with go1.8
  this fixes the golang.org/x/net/context conflict
* Thu Aug 24 2017 vrothberg@suse.com
- Update to version 0.8.0:
  * flannel reads from created subnet.env file on startup
  * Fix a bug with the iface-regex that always returned an error
  * Fix a bug where previously leased subnets would not update etcd leases
  * main.go: Fix logging options
  * Allow kube subnet manager to run outside of kubernetes
  * Added ability to specify multiple ifaces and iface regexes
  * Docs: Add kubernetes and troubleshooting info
  * Update manifest to v0.8.0
* Thu Aug 17 2017 vrothberg@suse.com
- Fix bsc#1054097
  * We need to patch the Version variable to align with the package version
  * Do this by using `gofmt` (linker flags can't be set without changing the build)
* Wed Apr 19 2017 opensuse-packaging@opensuse.org
- Update to version 0.7.1:
  * Add Kubernetes RBAC support
  * vendor: Revendor with more sensible pinnings
  * vendor: Make code compatible again
  * Simplify rbac creation process
  * Tolerate flannel running on master nodes
  * backend/vxlan: Don't recreate vxlan device on flanneld restart
  * backend/hostgw: Fix memory leak
  * Build tar.gz for ppc64le, arm and arm64 arch
  * kube-flannel: Add namespace for compatibility with RBAC rules
  * Explicitly state operator: Exists for master node toleration - as tolleration defaults to Equal by default which will result in the non scheduling of flannel on the master nodes
  * switch kube subnet manager to PATCH
  * Bump k8s manifest version to v0.7.1
  * Correct the image in the k8s manifest files
* Fri Jan 20 2017 opensuse-packaging@opensuse.org
- Update to version 0.7.0:
  * version: bump to v0.5.3+git
  * subnet: add infrastructure and tests for network watches
  * Refactoring: single ctx and pull out LeaseRenewer
  * Bug fix: remote mode errors out with bad backend type
  * Use a map for backend lookups
  * Split backend Init operation into New/Init and AddNetwork
  * Fix etcd implementation of getNetworks()
  * vendor: update etcd/client
  * aws-vpc: migrate to official AWS SDK
  * aws-vpc: use SDK to get metadata
  * Add network package to testing
  * Add/remove networks when registry changes
  * bug fix: no specified networks still led to multi-network path
  * Fix running multiple networks
  * Fix network watches when subnets change
  * Better handling of Ctrl+C
  * Add UnregisterNetwork backend method
  * Notify systemd service when server is ready to listen
  * Fix/improve docs
  * Masquerade host to flannel traffic.
  * Change copyright from CoreOS to flannel authors
  * remote: close response body during watch()
  * Refactor the backend interfaces for multi-networks
  * Go 1.5 compat change
  * test: add license header check + missing headers
  * travis: add logo to README, switch to go 1.4/1.5
  * build: use `git describe` output in version
  * file rename as separate commit for better diffs
  * Use jonboulle/clockwork
  * Have registry deal with subnet and not etcd types
  * Actually track backends in the active map
  * Fix subnet watch key creation
  * Periodically retry getting initial networks
  * Version embedding for Go 1.4 and 1.5
  * Ability to revoke lease
  * Add reservations to admin control subnet allocs
  * Revendor netlink library
  * Add mock etcd and etcd-backed registry testcases
  * tests: fix bug due to random numbers being used
  * Fixes a number of races
  * backend/udp: bind to the advertised interface
  * Add cli args for etcd basic auth
  * MAINTAINERS: remove eyakubovich; add tomdee, philips, steveej
  * DOCS: Add note to AWS docs about why it might be used
  * BUILDS: Use vendor directory instead of Godeps
  * Updating code.google.com/p/... dependencies
  * Add glide file
  * Add glide.lock and update GCE dependencies
  * Support quorum read option
  * vendor: bump netlink to latest master
  * network/ipmasq: RETURN instead of ACCEPT to allowe other rules
  * vendor: coreos/pkg: -> v2
  * vendor: bump netlink to latest
  * vxlan: support group-based policy
  * scripts/build: compat header
  * hostgw: Check existence of and compare routes before attempting to add/update them
  * backend/hostgw: don't filter by LinkIndex
  * BUILDS: Replace some shell scripts with Makefile
  * deps: Update go-iptables version
  * mk-docker-opts.sh: replace with busybox shell compatible version
  * BUILDS: Overhaul build process
  * vxlan: error on sysctl fail
  * Fix a typo in format error.
  * Makefile: Disable static builds of flanneld
  * Makefile: Make the ARCH part of the tag name not the image name
  * Builds: Insert libpthread into busybox images
  * The docker daemon syntax change addressed
  * Makefile: gzip the dist tar.gz file
  * Add functional (end-to-end) testing
  * README: Update build instructions
  * Makefile: Push "latest" to flannel-git on quay.io
  * Run e2e tests on travis
  * glide: cfg change
  * glide: add k8s deps
  * fixup after etcd client update
  * add kube backed subnet manager
  * Update aws-vpc-backend.md
  * README: Kubernetes rename
  * Documentation: Fix sample kube-flannel config
  * backend: do not log in Register
  * Makefile: Push tags to flannel-git for all builds
  * Makefile: clean before flannel-git build
  * Makefile: Also push :latest for flannel-git
  * Fixed #521: flanneld hang on at initialEvtsBatch := <-evts because of empty batch list in WatchLeases of subnet/watch.go
  * Make the flannel daemonset multiarch
  * aws-vpc: Fix crash when route has vpc-endpoints
  * aws-vpc: remove "blackholes"
  * deps: update aws-sdk version to latest stable
  * backend: fixes and cleanups in awsvpc backend
  * vxlan: user verbose logging macros
  * subnet/kube: Use informer callbacks for lease events
  * subnet/kube: wait for cache sync before using subnet manager
  * network manager: Improve logging
  * subnet/kube: modify a copy of node object, rather than the cached object
  * Fix a typo in backend/vxlan/network.go
  * Documention: Add information on leases and reservations
  * e2e: Allow the backend list to be overridden
  * backend/vxlan: Improve the comments and logging
  * backend/vxlan: Set the netmask of the IP used for the vxlan device
  * Add a flag to configure the subnet lease renewal margin. (#559)
  * Replacing the user id with group id.
  * Removing the -it flag from the docker build commands.
  * Update kube-flannel.yaml
  * Add note to readme about -kube-subnet-mgr
* Fri Nov 18 2016 opensuse-packaging@opensuse.org
- Update to version 0.5.5:
  * Remove code dup and use coreos/pkg/flagutil
  * version: bump to v0.5.3
  * aws-vpc: migrate to official AWS SDK
  * aws-vpc: use SDK to get metadata
  * Notify systemd service when server is ready to listen
  * Masquerade host to flannel traffic.
  * remote: close response body during watch()
  * version: bump to v0.5.4
  * Bug fix: running out of memory with vxlan+bonding
  * version: bump to v0.5.5
* Wed Sep 14 2016 opensuse-packaging@opensuse.org
- Update to version 0.6.1:
  * Support quorum read option
  * deps: Update go-iptables version
  * mk-docker-opts.sh: replace with busybox shell compatible version
  * BUILDS: Overhaul build process
  * vxlan: error on sysctl fail
  * Fix a typo in format error.
  * Makefile: Disable static builds of flanneld
  * Makefile: Make the ARCH part of the tag name not the image name
  * Builds: Insert libpthread into busybox images
  * Support VXLAN GBP
  * Add cli args for etcd basic auth
  * Add reservations to admin control subnet allocs
  * Ability to revoke lease
  * small docs changes
  * overhaul of the build system
  * improvements to stability and UX tweaks
  * refactoring mainly driven by reservation support
* Fri Jul 15 2016 kstreitova@suse.com
- clean specfile by spec-cleaner
- change 'PreReq: %%fillup_prereq' to 'Requires(post)'
* Thu Jul  7 2016 tboerger@suse.com
- Dropped rpmlintrc
- Refactoring of the spec based on golang-packaging
* Wed Jul  6 2016 msabate@suse.com
- Added go_provides
* Wed Jul  6 2016 msabate@suse.com
- Removed kernel-devel build requirement
  I've also added golang-packaging as a build requirement and we will be using
  the %%{go_nostrip} macro from that package. Moreover, I've done some minor
  improvements here and there.
* Tue Jul  5 2016 cbrauner@suse.com
- add %%ghost instruction: Files that are put into /run should be generated on
  the fly during runtime. To prevent them from getting installed we use
  %%ghost.
* Tue Jul  5 2016 cbrauner@suse.com
- add _constraints file to get more disk space on aarch64
* Tue Mar 22 2016 fcastelli@suse.com
- Fix issue inside of systemd unit file
* Mon Mar 21 2016 fcastelli@suse.com
- First release v0.5.5
